==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/ApplicationResource.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin

import com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ApplicationResource].
 */
@PulumiTagMarker
public class ApplicationResourceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApplicationResourceArgs = ApplicationResourceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApplicationResourceArgsBuilder.() -> Unit) {
        val builder = ApplicationResourceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ApplicationResource {
        val builtJavaResource =
            com.pulumi.azurenative.integrationspaces.ApplicationResource(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ApplicationResource(builtJavaResource)
    }
}

/**
 * A resource under application.
 * Azure REST API version: 2023-11-14-preview.
 * ## Example Usage
 * ### CreateOrUpdateApplicationResource
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var applicationResource = new AzureNative.IntegrationSpaces.ApplicationResource("applicationResource", new()
 *     {
 *         ApplicationName = "Application1",
 *         ResourceGroupName = "testrg",
 *         ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1",
 *         ResourceKind = "LogicApp",
 *         ResourceName = "Resource1",
 *         ResourceType = "Microsoft.Web/sites",
 *         SpaceName = "Space1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/integrationspaces/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := integrationspaces.NewApplicationResource(ctx, "applicationResource", &integrationspaces.ApplicationResourceArgs{
 * 			ApplicationName:   pulumi.String("Application1"),
 * 			ResourceGroupName: pulumi.String("testrg"),
 * 			ResourceId:        pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1"),
 * 			ResourceKind:      pulumi.String("LogicApp"),
 * 			ResourceName:      pulumi.String("Resource1"),
 * 			ResourceType:      pulumi.String("Microsoft.Web/sites"),
 * 			SpaceName:         pulumi.String("Space1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.integrationspaces.ApplicationResource;
 * import com.pulumi.azurenative.integrationspaces.ApplicationResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var applicationResource = new ApplicationResource("applicationResource", ApplicationResourceArgs.builder()
 *             .applicationName("Application1")
 *             .resourceGroupName("testrg")
 *             .resourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1")
 *             .resourceKind("LogicApp")
 *             .resourceName("Resource1")
 *             .resourceType("Microsoft.Web/sites")
 *             .spaceName("Space1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:integrationspaces:ApplicationResource Resource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.IntegrationSpaces/spaces/{spaceName}/applications/{applicationName}/resources/{resourceName}
 * ```
 */
public class ApplicationResource internal constructor(
    override val javaResource: com.pulumi.azurenative.integrationspaces.ApplicationResource,
) : KotlinCustomResource(javaResource, ApplicationResourceMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The status of the last operation.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The Arm id of the application resource.
     */
    public val resourceId: Output<String>
        get() = javaResource.resourceId().applyValue({ args0 -> args0 })

    /**
     * The kind of the application resource.
     */
    public val resourceKind: Output<String>?
        get() = javaResource.resourceKind().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the application resource.
     */
    public val resourceType: Output<String>
        get() = javaResource.resourceType().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApplicationResourceMapper : ResourceMapper<ApplicationResource> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.integrationspaces.ApplicationResource::class == javaResource::class

    override fun map(javaResource: Resource): ApplicationResource = ApplicationResource(
        javaResource
            as com.pulumi.azurenative.integrationspaces.ApplicationResource,
    )
}

/**
 * @see [ApplicationResource].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApplicationResource].
 */
public suspend fun applicationResource(
    name: String,
    block: suspend ApplicationResourceResourceBuilder.() -> Unit,
): ApplicationResource {
    val builder = ApplicationResourceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApplicationResource].
 * @param name The _unique_ name of the resulting resource.
 */
public fun applicationResource(name: String): ApplicationResource {
    val builder = ApplicationResourceResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/ApplicationResource.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin

import com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.integrationspaces.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ApplicationResource].
 */
@PulumiTagMarker
public class ApplicationResourceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApplicationResourceArgs = ApplicationResourceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApplicationResourceArgsBuilder.() -> Unit) {
        val builder = ApplicationResourceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ApplicationResource {
        val builtJavaResource =
            com.pulumi.azurenative.integrationspaces.ApplicationResource(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ApplicationResource(builtJavaResource)
    }
}

/**
 * A resource under application.
 * Azure REST API version: 2023-11-14-preview.
 * ## Example Usage
 * ### CreateOrUpdateApplicationResource
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var applicationResource = new AzureNative.IntegrationSpaces.ApplicationResource("applicationResource", new()
 *     {
 *         ApplicationName = "Application1",
 *         ResourceGroupName = "testrg",
 *         ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1",
 *         ResourceKind = "LogicApp",
 *         ResourceName = "Resource1",
 *         ResourceType = "Microsoft.Web/sites",
 *         SpaceName = "Space1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/integrationspaces/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := integrationspaces.NewApplicationResource(ctx, "applicationResource", &integrationspaces.ApplicationResourceArgs{
 * 			ApplicationName:   pulumi.String("Application1"),
 * 			ResourceGroupName: pulumi.String("testrg"),
 * 			ResourceId:        pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1"),
 * 			ResourceKind:      pulumi.String("LogicApp"),
 * 			ResourceName:      pulumi.String("Resource1"),
 * 			ResourceType:      pulumi.String("Microsoft.Web/sites"),
 * 			SpaceName:         pulumi.String("Space1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.integrationspaces.ApplicationResource;
 * import com.pulumi.azurenative.integrationspaces.ApplicationResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var applicationResource = new ApplicationResource("applicationResource", ApplicationResourceArgs.builder()
 *             .applicationName("Application1")
 *             .resourceGroupName("testrg")
 *             .resourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/testrg/providers/Microsoft.Web/sites/LogicApp1")
 *             .resourceKind("LogicApp")
 *             .resourceName("Resource1")
 *             .resourceType("Microsoft.Web/sites")
 *             .spaceName("Space1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:integrationspaces:ApplicationResource Resource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.IntegrationSpaces/spaces/{spaceName}/applications/{applicationName}/resources/{resourceName}
 * ```
 */
public class ApplicationResource internal constructor(
    override val javaResource: com.pulumi.azurenative.integrationspaces.ApplicationResource,
) : KotlinCustomResource(javaResource, ApplicationResourceMapper) {
    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The status of the last operation.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The Arm id of the application resource.
     */
    public val resourceId: Output<String>
        get() = javaResource.resourceId().applyValue({ args0 -> args0 })

    /**
     * The kind of the application resource.
     */
    public val resourceKind: Output<String>?
        get() = javaResource.resourceKind().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The type of the application resource.
     */
    public val resourceType: Output<String>
        get() = javaResource.resourceType().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApplicationResourceMapper : ResourceMapper<ApplicationResource> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.integrationspaces.ApplicationResource::class == javaResource::class

    override fun map(javaResource: Resource): ApplicationResource = ApplicationResource(
        javaResource
            as com.pulumi.azurenative.integrationspaces.ApplicationResource,
    )
}

/**
 * @see [ApplicationResource].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApplicationResource].
 */
public suspend fun applicationResource(
    name: String,
    block: suspend ApplicationResourceResourceBuilder.() -> Unit,
): ApplicationResource {
    val builder = ApplicationResourceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApplicationResource].
 * @param name The _unique_ name of the resulting resource.
 */
public fun applicationResource(name: String): ApplicationResource {
    val builder = ApplicationResourceResourceBuilder()
    builder.name(name)
    return builder.build()
}
